@@ -22,61 +22,33 @@
 #define __gda_field_h__ 1
 
 #include <glib.h>
-
-#ifdef HAVE_GOBJECT
-#  include <glib-object.h>
-#else
-#  include <gtk/gtkobject.h>
-#endif
-
+#include <gtk/gtkobject.h>
 #include <GDA.h>
+#include <gda-common-defs.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+G_BEGIN_DECLS
 
-typedef struct _GdaField      GdaField;
+typedef struct _GdaField GdaField;
 typedef struct _GdaFieldClass GdaFieldClass;
 
 #define GDA_TYPE_FIELD            (gda_field_get_type())
+#define GDA_FIELD(obj)            GTK_CHECK_CAST(obj, GDA_TYPE_FIELD, GdaField)
+#define GDA_FIELD_CLASS(klass)    GTK_CHECK_CLASS_CAST(klass, GDA_TYPE_FIELD, GdaFieldClass)
+#define GDA_IS_FIELD(obj)         GTK_CHECK_TYPE(obj, GDA_TYPE_FIELD)
+#define GDA_IS_FIELD_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GDA_TYPE_FIELD))
 
-#ifdef HAVE_GOBJECT
-#  define GDA_FIELD(obj) \
-            G_TYPE_CHECK_INSTANCE_CAST (obj, GDA_TYPE_FIELD, GdaField)
-#  define GDA_FIELD_CLASS(klass) \
-            G_TYPE_CHECK_CLASS_CAST (klass, GDA_TYPE_FIELD, GdaFieldClass)
-#  define IS_GDA_FIELD(obj) \
-            G_TYPE_CHECK_INSTANCE_TYPE (obj, GDA_TYPE_FIELD)
-#  define IS_GDA_FIELD_CLASS(klass) \
-            G_TYPE_CHECK_CLASS_TYPE (klass, GDA_TYPE_FIELD)
-#else
-#  define GDA_FIELD(obj)            GTK_CHECK_CAST(obj, GDA_TYPE_FIELD, GdaField)
-#  define GDA_FIELD_CLASS(klass)    GTK_CHECK_CLASS_CAST(klass, GDA_TYPE_FIELD, GdaFieldClass)
-#  define IS_GDA_FIELD(obj)         GTK_CHECK_TYPE(obj, GDA_TYPE_FIELD)
-#  define IS_GDA_FIELD_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GDA_TYPE_FIELD))
-#endif
+struct _GdaField {
+	GtkObject object;
 
-struct _GdaField
-{
-#ifdef HAVE_GOBJECT
-  GObject              object;
-#else
-  GtkObject            object;
-#endif
-  GDA_FieldAttributes* attributes;
-  gint                 actual_length;
-  GDA_FieldValue*      real_value;
-  GDA_FieldValue*      shadow_value;
-  GDA_FieldValue*      original_value;
+	GDA_FieldAttributes *attributes;
+	gint actual_length;
+	GDA_FieldValue *real_value;
+	GDA_FieldValue *shadow_value;
+	GDA_FieldValue *original_value;
 };
 
-struct _GdaFieldClass
-{
-#ifdef HAVE_GOBJECT
-  GObjectClass parent_class;
-#else
-  GtkObjectClass parent_class;
-#endif
+struct _GdaFieldClass {
+	GtkObjectClass parent_class;
 };
 
 #define gda_field_isnull(f)         (f->real_value ? (f)->real_value->_d : 1)
@@ -103,13 +75,14 @@ struct _GdaFieldClass
 #define gda_field_ubingint(f)       ((f)->real_value->_u.v._u.ull)
 #define gda_field_usmallint(f)      ((f)->real_value->_u.v._u.us)
 
-guint         gda_field_get_type        (void);
-GdaField*    gda_field_new             (void);
-gchar*        gda_fieldtype_2_string    (gchar* bfr, gint length, GDA_ValueType type);
-GDA_ValueType gda_string_2_fieldtype    (gchar *type);
-gchar*        gda_stringify_value       (gchar* bfr, gint length, GdaField* f);
+guint gda_field_get_type (void);
+GdaField *gda_field_new (void);
+gchar *gda_fieldtype_2_string (gchar * bfr, gint length,
+			       GDA_ValueType type);
+GDA_ValueType gda_string_2_fieldtype (gchar * type);
+gchar *gda_stringify_value (gchar * bfr, gint length, GdaField * f);
 
-gint          gda_field_actual_size     (GdaField* f);
+gint gda_field_actual_size (GdaField * f);
 #define       gda_field_defined_size(f) (f->attributes->definedSize)
 #define       gda_field_name(f)         (f->attributes->name)
 #define       gda_field_scale(f)        (f->attributes->scale)
@@ -117,8 +90,6 @@ gint          gda_field_actual_size     (GdaField* f);
 #define       gda_field_cType(f)        (f->attributes->cType)
 #define       gda_field_nativeType(f)   (f->attributes->nativeType)
 
-#ifdef __cplusplus
-}
-#endif
+G_END_DECLS
 
 #endif
