@@ -1,6 +1,9 @@
 /* GDA client libary
- * Copyright (C) 1998,1999 Michael Lausch
- * Copyright (C) 1999 Rodrigo Moya
+ * Copyright (C) 1998-2001 The Free Software Foundation
+ *
+ * AUTHORS:
+ *	Michael Lausch <michael@lausch.at>
+ *	Rodrigo Moya <rodrigo@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -21,9 +24,7 @@
 #include "config.h"
 #include "gda-recordset.h"
 
-#ifndef HAVE_GOBJECT
-#  include <gtk/gtksignal.h>
-#endif
+#include <gtk/gtksignal.h>
 
 enum {
 	RECORDSET_ERROR,
@@ -33,22 +34,17 @@ enum {
 	LAST_SIGNAL
 };
 
-static gint gda_recordset_signals[LAST_SIGNAL] = {0, };
+static gint gda_recordset_signals[LAST_SIGNAL] = { 0, };
 
-#ifdef HAVE_GOBJECT
-static void   gda_recordset_class_init (GdaRecordsetClass *klass,
-                                        gpointer data);
-static void   gda_recordset_init       (GdaRecordset *rs,
-                                        GdaRecordsetClass *klass);
-#else
-static void   gda_recordset_class_init (GdaRecordsetClass *);
-static void   gda_recordset_init       (GdaRecordset *);
-static void   gda_recordset_destroy    (GtkObject *object, gpointer user_data);
-#endif
+static void gda_recordset_class_init (GdaRecordsetClass *);
+static void gda_recordset_init (GdaRecordset *);
+static void gda_recordset_destroy (GtkObject * object, gpointer user_data);
 
-static void   gda_recordset_real_error (GdaRecordset *, GList *);
-static gulong fetch_and_store          (GdaRecordset* rs, gint count, gpointer bookmark);
-static gulong fetch_and_dont_store     (GdaRecordset* rs, gint count, gpointer bookmark);
+static void gda_recordset_real_error (GdaRecordset *, GList *);
+static gulong fetch_and_store (GdaRecordset * rs, gint count,
+			       gpointer bookmark);
+static gulong fetch_and_dont_store (GdaRecordset * rs, gint count,
+				    gpointer bookmark);
 
 /* per default there's no upper limit on the number of rows which can
  * be fetched from the data source
@@ -59,195 +55,155 @@ static gulong fetch_and_dont_store     (GdaRecordset* rs, gint count, gpointer b
 #define GDA_DEFAULT_CACHESIZE 64
 
 static void
-gda_recordset_real_error (GdaRecordset *rs, GList *error_list)
+gda_recordset_real_error (GdaRecordset * rs, GList * error_list)
 {
 	GdaConnection *cnc;
-	
-	g_return_if_fail(IS_GDA_CONNECTION(cnc));
-	
-	if ((cnc = gda_recordset_get_connection(rs))) {
-		gda_connection_add_errorlist(cnc, error_list);
+
+	g_return_if_fail (GDA_IS_CONNECTION (cnc));
+
+	if ((cnc = gda_recordset_get_connection (rs))) {
+		gda_connection_add_error_list (cnc, error_list);
 	}
 }
 
-#ifdef HAVE_GOBJECT
-GType
-gda_recordset_get_type (void)
-{
-	static GType type = 0;
-	
-	if (!type) {
-		GTypeInfo info = {
-			sizeof (GdaRecordsetClass),               /* class_size */
-			NULL,                                      /* base_init */
-			NULL,                                      /* base_finalize */
-			(GClassInitFunc) gda_recordset_class_init, /* class_init */
-			NULL,                                      /* class_finalize */
-			NULL,                                      /* class_data */
-			sizeof (GdaRecordset),                    /* instance_size */
-			0,                                         /* n_preallocs */
-			(GInstanceInitFunc) gda_recordset_init,    /* instance_init */
-			NULL,                                      /* value_table */
-		};
-		type = g_type_register_static (G_TYPE_OBJECT, "GdaRecordset", &info, 0);
-	}
-	return type;
-}
-#else
 guint
 gda_recordset_get_type (void)
 {
 	static guint gda_recordset_type = 0;
-	
+
 	if (!gda_recordset_type) {
 		GtkTypeInfo gda_recordset_info = {
 			"GdaRecordset",
-			sizeof(GdaRecordset),
-			sizeof(GdaRecordsetClass),
+			sizeof (GdaRecordset),
+			sizeof (GdaRecordsetClass),
 			(GtkClassInitFunc) gda_recordset_class_init,
 			(GtkObjectInitFunc) gda_recordset_init,
 			(GtkArgSetFunc) NULL,
 			(GtkArgSetFunc) NULL
 		};
-		gda_recordset_type = gtk_type_unique(gtk_object_get_type(), &gda_recordset_info);
+		gda_recordset_type =
+			gtk_type_unique (gtk_object_get_type (),
+					 &gda_recordset_info);
 	}
 	return (gda_recordset_type);
 }
-#endif
 
-#ifdef HAVE_GOBJECT
-static void
-gda_recordset_class_init (GdaRecordsetClass *klass, gpointer data)
-{
-	/* FIXME: No signals in GObject yet */
-	klass->error = gda_recordset_real_error;
-	klass->eof = NULL;
-	klass->bof = NULL;
-}
-#else
-typedef void (*GtkSignal_NONE__INT_POINTER)(GtkObject,
-                                            guint  arg1,
-                                            gpointer arg2,
-                                            gpointer user_data);
+typedef void (*GtkSignal_NONE__INT_POINTER) (GtkObject,
+					     guint arg1,
+					     gpointer arg2,
+					     gpointer user_data);
 
 static void
-gda_recordset_class_init (GdaRecordsetClass *klass)
+gda_recordset_class_init (GdaRecordsetClass * klass)
 {
-	GtkObjectClass* object_class = (GtkObjectClass *) klass;
+	GtkObjectClass *object_class = (GtkObjectClass *) klass;
 
 	gda_recordset_signals[RECORDSET_ERROR] =
-		gtk_signal_new("error",
-		               GTK_RUN_LAST,
-		               object_class->type,
-		               GTK_SIGNAL_OFFSET(GdaRecordsetClass, error),
-		               gtk_marshal_NONE__POINTER,
-		               GTK_TYPE_NONE,
-		               1,
-		               GTK_TYPE_POINTER);
+		gtk_signal_new ("error",
+				GTK_RUN_LAST,
+				object_class->type,
+				GTK_SIGNAL_OFFSET (GdaRecordsetClass, error),
+				gtk_marshal_NONE__POINTER,
+				GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
 	gda_recordset_signals[RECORDSET_EOF] =
-		gtk_signal_new("eof",
-		               GTK_RUN_LAST,
-		               object_class->type,
-		               GTK_SIGNAL_OFFSET(GdaRecordsetClass, eof),
-		               gtk_signal_default_marshaller,
-		               GTK_TYPE_NONE, 0);
+		gtk_signal_new ("eof",
+				GTK_RUN_LAST,
+				object_class->type,
+				GTK_SIGNAL_OFFSET (GdaRecordsetClass, eof),
+				gtk_signal_default_marshaller,
+				GTK_TYPE_NONE, 0);
 	gda_recordset_signals[RECORDSET_BOF] =
-		gtk_signal_new("bof",
-		               GTK_RUN_LAST,
-		               object_class->type,
-		               GTK_SIGNAL_OFFSET(GdaRecordsetClass, bof),
-		               gtk_signal_default_marshaller,
-		               GTK_TYPE_NONE, 0);
+		gtk_signal_new ("bof",
+				GTK_RUN_LAST,
+				object_class->type,
+				GTK_SIGNAL_OFFSET (GdaRecordsetClass, bof),
+				gtk_signal_default_marshaller,
+				GTK_TYPE_NONE, 0);
 	gda_recordset_signals[RECORDSET_ROW_CHANGED] =
-		gtk_signal_new("row_changed",
-		               GTK_RUN_LAST,
-		               object_class->type,
-		               GTK_SIGNAL_OFFSET(GdaRecordsetClass, row_changed),
-		               gtk_signal_default_marshaller,
-		               GTK_TYPE_NONE, 0);
+		gtk_signal_new ("row_changed",
+				GTK_RUN_LAST,
+				object_class->type,
+				GTK_SIGNAL_OFFSET (GdaRecordsetClass,
+						   row_changed),
+				gtk_signal_default_marshaller, GTK_TYPE_NONE,
+				0);
+
+	gtk_object_class_add_signals (object_class, gda_recordset_signals,
+				      LAST_SIGNAL);
 
-	gtk_object_class_add_signals(object_class, gda_recordset_signals, LAST_SIGNAL);
-	
 	klass->error = gda_recordset_real_error;
 	klass->eof = NULL;
 	klass->bof = NULL;
 	klass->row_changed = NULL;
 	object_class->destroy = gda_recordset_destroy;
 }
-#endif
 
 static void
-#ifdef HAVE_GOBJECT
-gda_recordset_init (GdaRecordset *rs, GdaRecordsetClass *klass)
+gda_recordset_init (GdaRecordset * rs)
 {
-#else
-gda_recordset_init (GdaRecordset *rs) {
-#endif
-	rs->external_cmd     = 0;
-	rs->internal_cmd     = 0;
-	rs->corba_rs         = CORBA_OBJECT_NIL;
-	rs->cnc              = 0;
-	rs->chunks           = 0;
-	rs->chunks_length    = 0;
-	rs->current_row      = 0;
+	rs->external_cmd = 0;
+	rs->internal_cmd = 0;
+	rs->corba_rs = CORBA_OBJECT_NIL;
+	rs->cnc = 0;
+	rs->chunks = 0;
+	rs->chunks_length = 0;
+	rs->current_row = 0;
 	rs->field_attributes = 0;
-	rs->max_index        = 0;
-	rs->maxrows          = 0;
-	rs->affected_rows    = 0;
-	rs->cachesize        = 0;
-	rs->open             = 0;
-	rs->eof              = 1;
-	rs->bof              = 1;
-	rs->readonly         = 1;
-	rs->cursor_location  = GDA_USE_CLIENT_CURSOR;
-	rs->cursor_type      = GDA_OPEN_FWDONLY;
-	rs->name             = 0;
+	rs->max_index = 0;
+	rs->maxrows = 0;
+	rs->affected_rows = 0;
+	rs->cachesize = 0;
+	rs->open = 0;
+	rs->eof = 1;
+	rs->bof = 1;
+	rs->readonly = 1;
+	rs->cursor_location = GDA_USE_CLIENT_CURSOR;
+	rs->cursor_type = GDA_OPEN_FWDONLY;
+	rs->name = 0;
 }
 
-#ifndef HAVE_GOBJECT
 static void
-gda_recordset_destroy (GtkObject *object, gpointer user_data)
+gda_recordset_destroy (GtkObject * object, gpointer user_data)
 {
 	GdaRecordset *rs = (GdaRecordset *) object;
 	GtkObjectClass *parent_class;
 
-	g_return_if_fail(IS_GDA_RECORDSET(rs));
+	g_return_if_fail (GDA_IS_RECORDSET (rs));
 
 	if (rs->open)
-		gda_recordset_close(rs);
+		gda_recordset_close (rs);
 	if (rs->internal_cmd) {
-		gda_command_free(rs->internal_cmd);
+		gda_command_free (rs->internal_cmd);
 	}
 
-	parent_class = gtk_type_class(gtk_object_get_type());
+	parent_class = gtk_type_class (gtk_object_get_type ());
 	if (parent_class && parent_class->destroy)
-		parent_class->destroy(object);
+		parent_class->destroy (object);
 }
-#endif
 
 static void
-free_chunks (GList* chunks)
+free_chunks (GList * chunks)
 {
-	GDA_Row* row;
-	GList*   ptr;
-	
+	GDA_Row *row;
+	GList *ptr;
+
 	ptr = chunks;
-	while(ptr) {
+	while (ptr) {
 		row = ptr->data;
-		CORBA_free(row);
-		ptr = g_list_next(ptr);
+		CORBA_free (row);
+		ptr = g_list_next (ptr);
 	}
 }
 
-static GDA_Row*
-row_by_idx (GdaRecordset* rs, gint idx)
+static GDA_Row *
+row_by_idx (GdaRecordset * rs, gint idx)
 {
-	GDA_Recordset_Chunk* chunk;
-	
-	if (idx <= 0 || idx > g_list_length(rs->chunks))
+	GDA_Recordset_Chunk *chunk;
+
+	if (idx <= 0 || idx > g_list_length (rs->chunks))
 		return 0;
-	chunk = g_list_nth(rs->chunks, idx-1)->data;
-	
+	chunk = g_list_nth (rs->chunks, idx - 1)->data;
+
 	return &chunk->_buffer[0];
 }
 
@@ -261,11 +217,7 @@ row_by_idx (GdaRecordset* rs, gint idx)
 GdaRecordset *
 gda_recordset_new (void)
 {
-#ifdef HAVE_GOBJECT
-	return GDA_RECORDSET (g_object_new (GDA_TYPE_RECORDSET, NULL));
-#else
-	return GDA_RECORDSET (gtk_type_new(gda_recordset_get_type()));
-#endif
+	return GDA_RECORDSET (gtk_type_new (gda_recordset_get_type ()));
 }
 
 /**
@@ -277,15 +229,11 @@ gda_recordset_new (void)
  *
  */
 void
-gda_recordset_free (GdaRecordset* rs)
+gda_recordset_free (GdaRecordset * rs)
 {
-	g_return_if_fail(IS_GDA_RECORDSET(rs));
+	g_return_if_fail (GDA_IS_RECORDSET (rs));
 
-#ifdef HAVE_GOBJECT
-	g_object_unref (G_OBJECT (rs));
-#else
 	gtk_object_unref (GTK_OBJECT (rs));
-#endif
 }
 
 /**
@@ -301,23 +249,23 @@ gda_recordset_free (GdaRecordset* rs)
  *
  */
 void
-gda_recordset_close (GdaRecordset* rs)
+gda_recordset_close (GdaRecordset * rs)
 {
 	CORBA_Environment ev;
-	
-	g_return_if_fail(IS_GDA_RECORDSET(rs));
-	
-	CORBA_exception_init(&ev);
+
+	g_return_if_fail (GDA_IS_RECORDSET (rs));
+
+	CORBA_exception_init (&ev);
 	if (!rs->open)
 		return;
 	rs->open = 0;
 	if (rs->corba_rs) {
-		GDA_Recordset_close(rs->corba_rs, &ev);
-		gda_connection_corba_exception(rs->cnc, &ev);
+		GDA_Recordset_close (rs->corba_rs, &ev);
+		gda_connection_corba_exception (rs->cnc, &ev);
 	}
 	rs->corba_rs = CORBA_OBJECT_NIL;
 	if (rs->chunks) {
-		free_chunks(rs->chunks);
+		free_chunks (rs->chunks);
 	}
 	rs->chunks = 0;
 }
@@ -335,10 +283,10 @@ gda_recordset_close (GdaRecordset* rs)
  * recordset is empty, FALSE otherwise.
  */
 gboolean
-gda_recordset_bof(GdaRecordset* rs)
+gda_recordset_bof (GdaRecordset * rs)
 {
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), 0);
-	
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), 0);
+
 	if (!rs->open || !rs->current_row || rs->bof)
 		return TRUE;
 	return FALSE;
@@ -357,53 +305,53 @@ gda_recordset_bof(GdaRecordset* rs)
  * recordset is empty, FALSE otherwise.
  */
 gboolean
-gda_recordset_eof (GdaRecordset* rs)
+gda_recordset_eof (GdaRecordset * rs)
 {
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), 0);
-	
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), 0);
+
 	if (!rs->open || rs->eof)
 		return TRUE;
 	return FALSE;
 }
 
 static gulong
-fetch_and_store(GdaRecordset* rs, gint count, gpointer bookmark)
+fetch_and_store (GdaRecordset * rs, gint count, gpointer bookmark)
 {
-	GDA_Recordset_Chunk* chunk;
-	gulong               current_idx;
-	CORBA_Environment    ev;
-	gint                 current_count;
-	
+	GDA_Recordset_Chunk *chunk;
+	gulong current_idx;
+	CORBA_Environment ev;
+	gint current_count;
+
 	current_idx = rs->current_index + count;
 	if (rs->chunks && current_idx <= rs->max_index && current_idx >= 0) {
 		/* don't care about direction, it's in our cache */
 		rs->bof = rs->eof = 0;
 		rs->current_index = current_idx;
-		rs->current_row = row_by_idx(rs, rs->current_index);
+		rs->current_row = row_by_idx (rs, rs->current_index);
 		return rs->current_index;
 	}
-	
+
 	if (count < 0) {
 		/* going backward  and underflow condition */
 		rs->eof = 0;
 		rs->bof = 1;
 		return rs->current_index;
 	}
-	
-	rs->eof = 0; /* be optimistic */
+
+	rs->eof = 0;		/* be optimistic */
 	rs->bof = 0;
-	
+
 	/* going forward. We have to fetch it from the provider */
-	CORBA_exception_init(&ev);
+	CORBA_exception_init (&ev);
 	for (current_count = 0; current_count < count; current_count++) {
-		chunk = GDA_Recordset_fetch(rs->corba_rs, 1, &ev);
-		if (gda_connection_corba_exception(rs->cnc, &ev)) {
+		chunk = GDA_Recordset_fetch (rs->corba_rs, 1, &ev);
+		if (gda_connection_corba_exception (rs->cnc, &ev)) {
 			/* An error */
 			return rs->current_index;
 		}
 		if (chunk->_length == 0) {
 			/* EOF. No more records there */
-			CORBA_free(chunk);
+			CORBA_free (chunk);
 			rs->current_index = rs->current_index + current_count;
 			rs->max_index = rs->current_index;
 			rs->eof = 1;
@@ -411,60 +359,62 @@ fetch_and_store(GdaRecordset* rs, gint count, gpointer bookmark)
 				rs->bof = 1;
 			return rs->current_index;
 		}
-		rs->chunks = g_list_append(rs->chunks, chunk);
-		if (gda_recordset_eof(rs)) {
+		rs->chunks = g_list_append (rs->chunks, chunk);
+		if (gda_recordset_eof (rs)) {
 			current_idx--;
 		}
 	}
 	rs->max_index = current_idx;
 	rs->current_index = current_idx;
-	rs->current_row = row_by_idx(rs, rs->current_index);
+	rs->current_row = row_by_idx (rs, rs->current_index);
+
 	return rs->current_index;
 }
-  
+
 static gulong
-fetch_and_dont_store(GdaRecordset* rs, gint count, gpointer bookmark)
+fetch_and_dont_store (GdaRecordset * rs, gint count, gpointer bookmark)
 {
-	GDA_Recordset_Chunk* chunk;
-	gulong               current_idx;
-	CORBA_Environment    ev;
-	GList*               error_list;
-	
+	GDA_Recordset_Chunk *chunk;
+	gulong current_idx;
+	CORBA_Environment ev;
+	GList *error_list;
+
 	current_idx = rs->current_index;
 	current_idx += count;
 	if (current_idx < 0)
 		return GDA_RECORDSET_INVALID_POSITION;
-	
-	CORBA_exception_init(&ev);
-	GDA_Recordset_moveFirst(rs->corba_rs, &ev);
-	error_list = gda_errors_from_exception(&ev);
+
+	CORBA_exception_init (&ev);
+	GDA_Recordset_moveFirst (rs->corba_rs, &ev);
+	error_list = gda_error_list_from_exception (&ev);
 	if (error_list) {
-		gda_connection_add_errorlist(rs->cnc, error_list);
+		gda_connection_add_error_list (rs->cnc, error_list);
 		return GDA_RECORDSET_INVALID_POSITION;
 	}
-	
-	GDA_Recordset_move(rs->corba_rs, current_idx-1, 0, &ev);
-	error_list = gda_errors_from_exception(&ev);
+
+	//GDA_Recordset_move (rs->corba_rs, current_idx - 1, 0, &ev);
+	//error_list = gda_error_list_from_exception (&ev);
+	//if (error_list) {
+	//gda_connection_add_error_list (rs->cnc, error_list);
+	//return GDA_RECORDSET_INVALID_POSITION;
+	//}
+	chunk = GDA_Recordset_fetch (rs->corba_rs, count, &ev);
+	error_list = gda_error_list_from_exception (&ev);
 	if (error_list) {
-		gda_connection_add_errorlist(rs->cnc, error_list);
+		gda_connection_add_error_list (rs->cnc, error_list);
 		return GDA_RECORDSET_INVALID_POSITION;
 	}
-	chunk = GDA_Recordset_fetch(rs->corba_rs, count, &ev);
-	error_list = gda_errors_from_exception(&ev);
-	if (error_list) {
-		gda_connection_add_errorlist(rs->cnc, error_list);
+
+	if (chunk->_length == 0)
 		return GDA_RECORDSET_INVALID_POSITION;
-	}
-	
-	if (chunk->_length == 0) return GDA_RECORDSET_INVALID_POSITION;
 	rs->current_index = current_idx;
 	if (rs->chunks) {
-		CORBA_free(rs->chunks->data);
-		g_list_free(rs->chunks);
+		CORBA_free (rs->chunks->data);
+		g_list_free (rs->chunks);
 		rs->chunks = 0;
 	}
-	rs->chunks = g_list_append(rs->chunks, chunk);
-	rs->current_row = row_by_idx(rs, rs->current_index);
+	rs->chunks = g_list_append (rs->chunks, chunk);
+	rs->current_row = row_by_idx (rs, rs->current_index);
 	return rs->current_index;
 }
 
@@ -495,26 +445,26 @@ fetch_and_dont_store(GdaRecordset* rs, gint count, gpointer bookmark)
  * fetching the rows.  
  */
 gulong
-gda_recordset_move (GdaRecordset* rs, gint count, gpointer bookmark)
+gda_recordset_move (GdaRecordset * rs, gint count, gpointer bookmark)
 {
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), GDA_RECORDSET_INVALID_POSITION);
-	g_return_val_if_fail(rs->corba_rs != NULL, GDA_RECORDSET_INVALID_POSITION);
-	g_return_val_if_fail(rs->open, GDA_RECORDSET_INVALID_POSITION);
-	
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), GDA_RECORDSET_INVALID_POSITION);
+	g_return_val_if_fail (rs->corba_rs != NULL, GDA_RECORDSET_INVALID_POSITION);
+	g_return_val_if_fail (rs->open, GDA_RECORDSET_INVALID_POSITION);
+
 	if (rs->cursor_type == GDA_OPEN_FWDONLY && count < 0)
 		return rs->current_index;
-	
+
 	if (count == 0)
 		return rs->current_index;
-	
+
 	if (rs->cursor_location == GDA_USE_CLIENT_CURSOR)
-		fetch_and_store(rs, count, 0);
-	else fetch_and_dont_store(rs, count, 0);
-	
+		fetch_and_store (rs, count, 0);
+	else
+		fetch_and_dont_store (rs, count, 0);
+
 	/* emit "row_changed" signal for data-bound widgets */
-#ifndef HAVE_GOBJECT   /* FIXME */
-	gtk_signal_emit(GTK_OBJECT(rs), gda_recordset_signals[RECORDSET_ROW_CHANGED]);
-#endif
+	gtk_signal_emit (GTK_OBJECT (rs),
+			 gda_recordset_signals[RECORDSET_ROW_CHANGED]);
 	return rs->current_index;
 }
 
@@ -531,21 +481,23 @@ gda_recordset_move (GdaRecordset* rs, gint count, gpointer bookmark)
  * if there was an error. 
  */
 gulong
-gda_recordset_move_first (GdaRecordset* rs)
+gda_recordset_move_first (GdaRecordset * rs)
 {
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), GDA_RECORDSET_INVALID_POSITION);
-	
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs),
+			      GDA_RECORDSET_INVALID_POSITION);
+
 	if (rs->cursor_location == GDA_USE_CLIENT_CURSOR) {
-		GDA_Recordset_Chunk* chunk;
+		GDA_Recordset_Chunk *chunk;
 		if (!rs->chunks)
-			return gda_recordset_move(rs, 1, 0);
+			return gda_recordset_move (rs, 1, 0);
 		rs->current_index = 1;
 		chunk = rs->chunks->data;
 		rs->current_row = &chunk->_buffer[0];
 		rs->eof = 0;
 		return 0;
 	}
-	gda_log_error("gda_recordset_move_first for server based cursor NIY");
+	gda_log_error
+		("gda_recordset_move_first for server based cursor NIY");
 	return GDA_RECORDSET_INVALID_POSITION;
 }
 
@@ -562,26 +514,28 @@ gda_recordset_move_first (GdaRecordset* rs)
  * if there was an error. 
  */
 gulong
-gda_recordset_move_last (GdaRecordset* rs)
+gda_recordset_move_last (GdaRecordset * rs)
 {
 	gulong pos;
 	gulong rc;
-	
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), GDA_RECORDSET_INVALID_POSITION);
-	
+
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs),
+			      GDA_RECORDSET_INVALID_POSITION);
+
 	if (rs->cursor_location == GDA_USE_CLIENT_CURSOR) {
 		pos = rs->current_index;
 		while (1) {
-			rc = gda_recordset_move(rs, 1, 0);
-			
+			rc = gda_recordset_move (rs, 1, 0);
+
 			if (rc == GDA_RECORDSET_INVALID_POSITION)
 				return GDA_RECORDSET_INVALID_POSITION;
-			if (gda_recordset_eof(rs))
+			if (gda_recordset_eof (rs))
 				return pos;
 			pos++;
 		}
 	}
-	gda_log_error("gda_recordset_move_first for server based cursor NIY");
+	gda_log_error
+		("gda_recordset_move_first for server based cursor NIY");
 	return GDA_RECORDSET_INVALID_POSITION;
 }
 
@@ -598,10 +552,10 @@ gda_recordset_move_last (GdaRecordset* rs)
  * if there was an error. 
  */
 gulong
-gda_recordset_move_next (GdaRecordset* rs)
+gda_recordset_move_next (GdaRecordset * rs)
 {
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), GDA_RECORDSET_INVALID_POSITION);
-	return gda_recordset_move(rs, 1, 0);
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), GDA_RECORDSET_INVALID_POSITION);
+	return gda_recordset_move (rs, 1, 0);
 }
 
 /**
@@ -609,9 +563,10 @@ gda_recordset_move_next (GdaRecordset* rs)
  * @rs: the recordset
  */
 gulong
-gda_recordset_move_prev (GdaRecordset *rs)
+gda_recordset_move_prev (GdaRecordset * rs)
 {
-	return -1;
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), GDA_RECORDSET_INVALID_POSITION);
+	return gda_recordset_move (rs, -1, 0);
 }
 
 /**
@@ -625,33 +580,76 @@ gda_recordset_move_prev (GdaRecordset *rs)
  * Returns: a pointer to a field structor or NULL if 
  * @idx is out of range
  */
-GdaField*
-gda_recordset_field_idx (GdaRecordset* rs, gint idx)
+GdaField *
+gda_recordset_field_idx (GdaRecordset * rs, gint idx)
 {
-	gint       rowsize;
-	GdaField* rc;
-	
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), 0);
-	g_return_val_if_fail(idx >= 0, 0);
-	g_return_val_if_fail(rs->open, 0);
-	
+	gint rowsize;
+	GdaField *rc;
+
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), 0);
+	g_return_val_if_fail (idx >= 0, 0);
+	g_return_val_if_fail (rs->open, 0);
+
 	if (!rs->current_row && !rs->field_attributes) {
-		g_warning("This shouldn't happen. Inconsistent recordset\n");
+		g_warning ("This shouldn't happen. Inconsistent recordset\n");
 		return 0;
 	}
 	rowsize = rs->field_attributes->_length;
 	if (idx >= rowsize)
 		return 0;
-	rc = gda_field_new();
+	rc = gda_field_new ();
 	rc->attributes = &rs->field_attributes->_buffer[idx];
 	if (rs->current_row) {
-		rc->real_value =  &rs->current_row->_buffer[idx].realValue;
+		rc->real_value = &rs->current_row->_buffer[idx].realValue;
 		rc->shadow_value = &rs->current_row->_buffer[idx].shadowValue;
-		rc->original_value = &rs->current_row->_buffer[idx].originalValue;
+		rc->original_value =
+			&rs->current_row->_buffer[idx].originalValue;
 	}
 	return rc;
 }
 
+/**
+ * gda_recordset_to_array:
+ * @rs: the recordset
+ *
+ * Returns a pointer array containing the whole recordset. Each node in
+ * the returned array is a GPtrArray, which in turn contains GdaField's
+ * as its nodes.
+ **/
+
+GPtrArray *
+gda_recordset_to_array (GdaRecordset *rs)
+{
+	GPtrArray *array, *row;
+	GdaField *rc;
+	gint fields, j;
+	gulong position;
+	
+	g_return_val_if_fail (GDA_IS_RECORDSET(rs), 0);
+	g_return_val_if_fail (rs->open, 0);
+	
+	position = gda_recordset_move_first (rs);
+	fields = gda_recordset_rowsize (rs);
+
+	array = g_ptr_array_new();
+
+	while (position != GDA_RECORDSET_INVALID_POSITION &&
+	       !gda_recordset_eof (rs)) {
+		row = g_ptr_array_new(); 
+
+		for (j = 0; j < fields; j++) {
+			rc = gda_recordset_field_idx(rs, j);
+			g_ptr_array_add(row, rc);
+		}
+		
+		g_ptr_array_add(array, row);
+
+		position = gda_recordset_move_next (rs);
+	}
+
+	return array;
+}
+
 /**
  * gda_recordset_field_name:
  * @rs: the recordset
@@ -664,22 +662,23 @@ gda_recordset_field_idx (GdaRecordset* rs, gint idx)
  * @idx is out of range
  */
 GdaField *
-gda_recordset_field_name (GdaRecordset* rs, gchar* name)
+gda_recordset_field_name (GdaRecordset * rs, gchar * name)
 {
 	gint rowsize;
 	gint idx;
-	
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), 0);
-	g_return_val_if_fail(rs->open, 0);
-	
+
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), 0);
+	g_return_val_if_fail (rs->open, 0);
+
 	if (!rs->current_row && !rs->field_attributes) {
-		g_warning("This shouldn't happen. Inconsistent recordset\n");
+		g_warning ("This shouldn't happen. Inconsistent recordset\n");
 		return 0;
 	}
 	rowsize = rs->field_attributes->_length;
 	for (idx = 0; idx < rowsize; idx++) {
-		if (strcasecmp(rs->field_attributes->_buffer[idx].name, name) == 0)
-			return gda_recordset_field_idx(rs, idx);
+		if (strcasecmp (rs->field_attributes->_buffer[idx].name, name)
+		    == 0)
+			return gda_recordset_field_idx (rs, idx);
 	}
 	return 0;
 }
@@ -691,13 +690,13 @@ gda_recordset_field_name (GdaRecordset* rs, gchar* name)
  * Returns the number of fields in a row of the current recordset
  */
 gint
-gda_recordset_rowsize (GdaRecordset* rs)
+gda_recordset_rowsize (GdaRecordset * rs)
 {
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), -1);
-	g_return_val_if_fail(rs->open, -1);
-	
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), -1);
+	g_return_val_if_fail (rs->open, -1);
+
 	if (!rs->current_row && !rs->field_attributes) {
-		g_warning("This shouldn't happen. Inconsistent recordset\n");
+		g_warning ("This shouldn't happen. Inconsistent recordset\n");
 		return 0;
 	}
 	return rs->field_attributes->_length;
@@ -710,9 +709,9 @@ gda_recordset_rowsize (GdaRecordset* rs)
  * Return the number of affected rows in the recordset
  */
 gulong
-gda_recordset_affected_rows (GdaRecordset *rs)
+gda_recordset_affected_rows (GdaRecordset * rs)
 {
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), 0);
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), 0);
 	return rs->affected_rows;
 }
 
@@ -730,11 +729,12 @@ gda_recordset_affected_rows (GdaRecordset *rs)
  * Returns: 0 if everyhting is okay, -1 on error
  */
 gint
-gda_recordset_set_connection (GdaRecordset* rs, GdaConnection* cnc)
+gda_recordset_set_connection (GdaRecordset * rs, GdaConnection * cnc)
 {
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), -1);
-	
-	if (rs->open) return -1;
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), -1);
+
+	if (rs->open)
+		return -1;
 	rs->cnc = cnc;
 	return 0;
 }
@@ -747,11 +747,11 @@ gda_recordset_set_connection (GdaRecordset* rs, GdaConnection* cnc)
  * the recordset isn't open or there's no connection assoctiated with
  * this recordset.
  */
-GdaConnection*
-gda_recordset_get_connection (GdaRecordset* rs)
+GdaConnection *
+gda_recordset_get_connection (GdaRecordset * rs)
 {
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), NULL);
-	
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), NULL);
+
 	if (!rs->open)
 		return NULL;
 	return rs->cnc;
@@ -776,49 +776,48 @@ gda_recordset_get_connection (GdaRecordset* rs)
  * Returns: 0 if everytrhing is okay, -1 on error
  */
 gint
-gda_recordset_open (GdaRecordset* rs,
-                    GdaCommand* cmd,
-                    GDA_CursorType cursor_type,
-                    GDA_LockType lock_type,
-                    gulong options)
+gda_recordset_open (GdaRecordset * rs,
+		    GdaCommand * cmd,
+		    GDA_CursorType cursor_type,
+		    GDA_LockType lock_type, gulong options)
 {
-	CORBA_Environment    ev;
-	GDA_CmdParameterSeq* corba_parameters;
-	CORBA_long           affected = 0;
-	GList*               error_list;
-	
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), -1);
-	g_return_val_if_fail(!rs->open, -1);
+	CORBA_Environment ev;
+	GDA_CmdParameterSeq *corba_parameters;
+	CORBA_long affected = 0;
+	GList *error_list;
 
-#ifdef HAVE_GOBJECT
-	gda_recordset_init (rs, NULL);    /* FIXME: calling the constructor here */
-#else                               /* is not very beautiful */
-	gda_recordset_init(rs);
-#endif
-	corba_parameters = __gda_command_get_params(cmd);
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), -1);
+	g_return_val_if_fail (!rs->open, -1);
+
+	gda_recordset_init (rs);
+	corba_parameters = __gda_command_get_params (cmd);
 	rs->cursor_type = cursor_type;
-	rs->lock_type   = lock_type;
-	CORBA_exception_init(&ev);
+	rs->lock_type = lock_type;
+	CORBA_exception_init (&ev);
 	rs->cnc = cmd->connection;
-	rs->corba_rs = GDA_Command_open(cmd->command, corba_parameters,
-	                                cursor_type, lock_type, &affected, &ev);
-	error_list = gda_errors_from_exception(&ev);
+	rs->corba_rs = GDA_Command_open (cmd->command, corba_parameters,
+					 cursor_type, lock_type, &affected,
+					 &ev);
+	error_list = gda_error_list_from_exception (&ev);
 	if (error_list) {
 		rs->corba_rs = 0;
-		gda_connection_add_errorlist(rs->cnc, error_list);
+		gda_connection_add_error_list (rs->cnc, error_list);
 		return -1;
 	}
-	
-	if (CORBA_Object_is_nil(rs->corba_rs, &ev)) {
-		error_list = gda_errors_from_exception(&ev);
-		if (error_list) gda_connection_add_errorlist(rs->cnc, error_list);
+
+	if (CORBA_Object_is_nil (rs->corba_rs, &ev)) {
+		error_list = gda_error_list_from_exception (&ev);
+		if (error_list)
+			gda_connection_add_error_list (rs->cnc, error_list);
 		rs->field_attributes = NULL;
 		return -1;
 	}
-	else rs->field_attributes = GDA_Recordset_describe(rs->corba_rs, &ev);
-	error_list = gda_errors_from_exception(&ev);
+	else
+		rs->field_attributes =
+			GDA_Recordset_describe (rs->corba_rs, &ev);
+	error_list = gda_error_list_from_exception (&ev);
 	if (error_list) {
-		gda_connection_add_errorlist(rs->cnc, error_list);
+		gda_connection_add_error_list (rs->cnc, error_list);
 		return -1;
 	}
 	rs->open = 1;
@@ -845,28 +844,28 @@ gda_recordset_open (GdaRecordset* rs,
  * Returns: 0 if everytrhing is okay, -1 on error
  */
 gint
-gda_recordset_open_txt (GdaRecordset* rs,
-                        gchar* txt,
-                        GDA_CursorType cursor_type,
-                        GDA_LockType lock_type,
-                        gulong options)
+gda_recordset_open_txt (GdaRecordset * rs,
+			gchar * txt,
+			GDA_CursorType cursor_type,
+			GDA_LockType lock_type, gulong options)
 {
-	CORBA_Environment  ev;
-	GdaCommand*       cmd;
-	gint               rc;
-	
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), -1);
-	
-	if (rs->open) return -1;
-	
+	CORBA_Environment ev;
+	GdaCommand *cmd;
+	gint rc;
+
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), -1);
+
+	if (rs->open)
+		return -1;
+
 	rs->cursor_type = cursor_type;
-	rs->lock_type   = lock_type;
-	CORBA_exception_init(&ev);
-	cmd = gda_command_new();
-	gda_command_set_connection(cmd, rs->cnc);
-	gda_command_set_text(cmd, txt);
-	rc = gda_recordset_open(rs, cmd, cursor_type, lock_type, options);
-	gda_command_free(cmd);
+	rs->lock_type = lock_type;
+	CORBA_exception_init (&ev);
+	cmd = gda_command_new ();
+	gda_command_set_connection (cmd, rs->cnc);
+	gda_command_set_text (cmd, txt);
+	rc = gda_recordset_open (rs, cmd, cursor_type, lock_type, options);
+	gda_command_free (cmd);
 	return rc;
 }
 
@@ -874,36 +873,51 @@ gda_recordset_open_txt (GdaRecordset* rs,
  * gda_recordset_add_field
  */
 gint
-gda_recordset_add_field (GdaRecordset* rs, GdaField* field)
+gda_recordset_add_field (GdaRecordset * rs, GdaField * field)
 {
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), -1);
-	g_return_val_if_fail(IS_GDA_FIELD(field), -1);
-	g_return_val_if_fail(field->attributes, -1);
-	g_return_val_if_fail(field->attributes->name, -1);
-	
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), -1);
+	g_return_val_if_fail (GDA_IS_FIELD (field), -1);
+	g_return_val_if_fail (field->attributes, -1);
+	g_return_val_if_fail (field->attributes->name, -1);
+
 	if (rs->field_attributes) {
-		GDA_FieldAttributes* old;
-		gint                 idx;
-		
+		GDA_FieldAttributes *old;
+		gint idx;
+
 		for (idx = 0; idx < rs->field_attributes->_length; idx++) {
-			if (strcasecmp(rs->field_attributes->_buffer[idx].name,
-			               field->attributes->name) == 0)
+			if (strcasecmp
+			    (rs->field_attributes->_buffer[idx].name,
+			     field->attributes->name) == 0)
 				return -1;
 		}
 		rs->field_attributes->_length++;
 		old = rs->field_attributes->_buffer;
-		rs->field_attributes->_buffer = CORBA_sequence_GDA_FieldAttributes_allocbuf(rs->field_attributes->_length);
-		memcpy(rs->field_attributes->_buffer, old, rs->field_attributes->_length - 1);
+		rs->field_attributes->_buffer =
+			CORBA_sequence_GDA_FieldAttributes_allocbuf (rs->
+								     field_attributes->
+								     _length);
+		memcpy (rs->field_attributes->_buffer, old,
+			rs->field_attributes->_length - 1);
 	}
 	else {
 		rs->field_attributes->_length = 1;
-		rs->field_attributes->_buffer = CORBA_sequence_GDA_FieldAttributes_allocbuf(rs->field_attributes->_length);
+		rs->field_attributes->_buffer =
+			CORBA_sequence_GDA_FieldAttributes_allocbuf (rs->
+								     field_attributes->
+								     _length);
 	}
-	rs->field_attributes->_buffer[rs->field_attributes->_length-1].definedSize = field->attributes->definedSize;
-	rs->field_attributes->_buffer[rs->field_attributes->_length-1].name = CORBA_string_dup(field->attributes->name);
-	rs->field_attributes->_buffer[rs->field_attributes->_length-1].scale = field->attributes->scale;
-	rs->field_attributes->_buffer[rs->field_attributes->_length-1].gdaType = field->attributes->gdaType;
-	rs->field_attributes->_buffer[rs->field_attributes->_length-1].cType = field->attributes->cType;
+	rs->field_attributes->_buffer[rs->field_attributes->_length -
+				      1].definedSize =
+		field->attributes->definedSize;
+	rs->field_attributes->_buffer[rs->field_attributes->_length -
+				      1].name =
+		CORBA_string_dup (field->attributes->name);
+	rs->field_attributes->_buffer[rs->field_attributes->_length -
+				      1].scale = field->attributes->scale;
+	rs->field_attributes->_buffer[rs->field_attributes->_length -
+				      1].gdaType = field->attributes->gdaType;
+	rs->field_attributes->_buffer[rs->field_attributes->_length -
+				      1].cType = field->attributes->cType;
 	return 0;
 }
 
@@ -914,9 +928,9 @@ gda_recordset_add_field (GdaRecordset* rs, GdaField* field)
  * Returns: the current value of the cursor location attribute
  */
 GDA_CursorLocation
-gda_recordset_get_cursorloc (GdaRecordset* rs)
+gda_recordset_get_cursorloc (GdaRecordset * rs)
 {
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), -1);
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), -1);
 	return rs->cursor_location;
 }
 
@@ -929,9 +943,9 @@ gda_recordset_get_cursorloc (GdaRecordset* rs)
  */
 
 void
-gda_recordset_set_cursorloc(GdaRecordset* rs, GDA_CursorLocation loc)
+gda_recordset_set_cursorloc (GdaRecordset * rs, GDA_CursorLocation loc)
 {
-	g_return_if_fail(IS_GDA_RECORDSET(rs));
+	g_return_if_fail (GDA_IS_RECORDSET (rs));
 	rs->cursor_location = loc;
 }
 
@@ -942,9 +956,9 @@ gda_recordset_set_cursorloc(GdaRecordset* rs, GDA_CursorLocation loc)
  * Returns: the current value of the cursor type attriburte
  */
 GDA_CursorType
-gda_recordset_get_cursortype(GdaRecordset* rs)
+gda_recordset_get_cursortype (GdaRecordset * rs)
 {
-	g_return_val_if_fail(IS_GDA_RECORDSET(rs), -1);
+	g_return_val_if_fail (GDA_IS_RECORDSET (rs), -1);
 	return rs->cursor_type;
 }
 
@@ -956,8 +970,8 @@ gda_recordset_get_cursortype(GdaRecordset* rs)
  * Set the cursor type attribute to @type.
  */
 void
-gda_recordset_set_cursortype(GdaRecordset* rs, GDA_CursorType type)
+gda_recordset_set_cursortype (GdaRecordset * rs, GDA_CursorType type)
 {
-	g_return_if_fail(IS_GDA_RECORDSET(rs));
+	g_return_if_fail (GDA_IS_RECORDSET (rs));
 	rs->cursor_type = type;
 }
