@@ -26,26 +26,28 @@
  * Public functions
  */
 gboolean
-gda_ldap_command_new (GdaServerCommand *cmd) {
+gda_ldap_command_new (GdaServerCommand * cmd)
+{
 	return TRUE;
 }
 
 GdaServerRecordset *
-gda_ldap_command_execute (GdaServerCommand *cmd,
-                          GdaServerError *error,
-                          const GDA_CmdParameterSeq *params,
-                          gulong *affected,
-                          gulong options) {
-	GdaServerRecordset* recset = NULL;
-	
-	switch (gda_server_command_get_type(cmd)) {
-		case GDA_COMMAND_TYPE_TEXT :
-		case GDA_COMMAND_TYPE_TABLE :
-		case GDA_COMMAND_TYPE_STOREDPROCEDURE :
+gda_ldap_command_execute (GdaServerCommand * cmd,
+			  GdaServerError * error,
+			  const GDA_CmdParameterSeq * params,
+			  gulong * affected, gulong options)
+{
+	GdaServerRecordset *recset = NULL;
+
+	switch (gda_server_command_get_cmd_type (cmd)) {
+	case GDA_COMMAND_TYPE_TEXT:
+	case GDA_COMMAND_TYPE_TABLE:
+	case GDA_COMMAND_TYPE_STOREDPROCEDURE:
 	}
 	return recset;
 }
 
 void
-gda_ldap_command_free (GdaServerCommand *cmd) {
+gda_ldap_command_free (GdaServerCommand * cmd)
+{
 }
