@@ -46,70 +46,75 @@
  */
 typedef struct
 {
-} Mail_Connection;
+}
+Mail_Connection;
 
 typedef struct
 {
-} Mail_Command;
+}
+Mail_Command;
 
 typedef struct
 {
 	Mail_Command ml_cmd;
-} Mail_Recordset;
+}
+Mail_Recordset;
 
 /*
  * Server implementation prototypes
  */
 gboolean gda_mail_connection_new (GdaServerConnection * cnc);
 gint gda_mail_connection_open (GdaServerConnection * cnc,
-							   const gchar * dsn,
-							   const gchar * user,
-							   const gchar * password);
+			       const gchar * dsn,
+			       const gchar * user, const gchar * password);
 void gda_mail_connection_close (GdaServerConnection * cnc);
 gint gda_mail_connection_begin_transaction (GdaServerConnection * cnc);
 gint gda_mail_connection_commit_transaction (GdaServerConnection * cnc);
 gint gda_mail_connection_rollback_transaction (GdaServerConnection * cnc);
-GdaServerRecordset* gda_mail_connection_open_schema (GdaServerConnection * cnc,
-													  GdaServerError * error,
-													  GDA_Connection_QType t,
-													  GDA_Connection_Constraint * constraints,
-													  gint length);
-glong gda_mail_connection_modify_schema (GdaServerConnection *cnc,
-                                         GDA_Connection_QType t,
-                                         GDA_Connection_Constraint *constraints,
-                                         gint length);
+GdaServerRecordset *gda_mail_connection_open_schema (GdaServerConnection *
+						     cnc,
+						     GdaServerError * error,
+						     GDA_Connection_QType t,
+						     GDA_Connection_Constraint
+						     * constraints,
+						     gint length);
+glong gda_mail_connection_modify_schema (GdaServerConnection * cnc,
+					 GDA_Connection_QType t,
+					 GDA_Connection_Constraint *
+					 constraints, gint length);
 gint gda_mail_connection_start_logging (GdaServerConnection * cnc,
-										const gchar * filename);
+					const gchar * filename);
 gint gda_mail_connection_stop_logging (GdaServerConnection * cnc);
-gchar* gda_mail_connection_create_table (GdaServerConnection * cnc,
-										 GDA_RowAttributes * columns);
+gchar *gda_mail_connection_create_table (GdaServerConnection * cnc,
+					 GDA_RowAttributes * columns);
 gboolean gda_mail_connection_supports (GdaServerConnection * cnc,
-									   GDA_Connection_Feature feature);
+				       GDA_Connection_Feature feature);
 GDA_ValueType gda_mail_connection_get_gda_type (GdaServerConnection * cnc,
-												gulong sql_type);
+						gulong sql_type);
 gshort gda_mail_connection_get_c_type (GdaServerConnection * cnc,
-									   GDA_ValueType type);
-gchar* gda_mail_connection_sql2xml (GdaServerConnection *cnc, const gchar *sql);
-gchar* gda_mail_connection_xml2sql (GdaServerConnection *cnc, const gchar *xml);
+				       GDA_ValueType type);
+gchar *gda_mail_connection_sql2xml (GdaServerConnection * cnc,
+				    const gchar * sql);
+gchar *gda_mail_connection_xml2sql (GdaServerConnection * cnc,
+				    const gchar * xml);
 void gda_mail_connection_free (GdaServerConnection * cnc);
 
 gboolean gda_mail_command_new (GdaServerCommand * cmd);
-GdaServerRecordset* gda_mail_command_execute (GdaServerCommand * cmd,
-											   GdaServerError * error,
-											   const GDA_CmdParameterSeq * params,
-											   gulong * affected,
-											   gulong options);
+GdaServerRecordset *gda_mail_command_execute (GdaServerCommand * cmd,
+					      GdaServerError * error,
+					      const GDA_CmdParameterSeq *
+					      params, gulong * affected,
+					      gulong options);
 void gda_mail_command_free (GdaServerCommand * cmd);
 
-gboolean gda_mail_recordset_new       (GdaServerRecordset * recset);
-gint     gda_mail_recordset_move_next (GdaServerRecordset * recset);
-gint     gda_mail_recordset_move_prev (GdaServerRecordset * recset);
-gint     gda_mail_recordset_close     (GdaServerRecordset * recset);
-void     gda_mail_recordset_free      (GdaServerRecordset * recset);
+gboolean gda_mail_recordset_new (GdaServerRecordset * recset);
+gint gda_mail_recordset_move_next (GdaServerRecordset * recset);
+gint gda_mail_recordset_move_prev (GdaServerRecordset * recset);
+gint gda_mail_recordset_close (GdaServerRecordset * recset);
+void gda_mail_recordset_free (GdaServerRecordset * recset);
 
 void gda_mail_error_make (GdaServerError * error,
-						  GdaServerRecordset * recset,
-						  GdaServerConnection * cnc,
-						  gchar * where);
+			  GdaServerRecordset * recset,
+			  GdaServerConnection * cnc, gchar * where);
 
 #endif
