@@ -1,5 +1,5 @@
 /* 
- * $Id: gda-tds-command.h,v 1.2 2001/04/07 08:49:34 rodrigo Exp $
+ * $Id: gda-tds-command.h,v 1.3 2001/07/18 23:05:43 vivien Exp $
  *
  * GNOME DB tds Provider
  * Copyright (C) 2000 Holger Thon
@@ -37,20 +37,22 @@
  * Per-object specific structures
  */
 
-typedef struct _tds_Command {
-  CS_COMMAND               *cmd;
-} tds_Command;
+typedef struct _tds_Command
+{
+	CS_COMMAND *cmd;
+}
+tds_Command;
 
 /*
  * Server implementation prototypes
  */
 
-gboolean gda_tds_command_new (GdaServerCommand *cmd);
-GdaServerRecordset* gda_tds_command_execute (GdaServerCommand *cmd,
-                                              GdaServerError *error,
-                                              const GDA_CmdParameterSeq *params,
-                                              gulong *affected,
-                                              gulong options);
-void gda_tds_command_free (GdaServerCommand *cmd);
+gboolean gda_tds_command_new (GdaServerCommand * cmd);
+GdaServerRecordset *gda_tds_command_execute (GdaServerCommand * cmd,
+					     GdaServerError * error,
+					     const GDA_CmdParameterSeq *
+					     params, gulong * affected,
+					     gulong options);
+void gda_tds_command_free (GdaServerCommand * cmd);
 
 #endif
